From 315fa06c75d023ef3e4285842dd730a4d94b78d6 Mon Sep 17 00:00:00 2001
From: Justin Clark-Casey (justincc)
Date: Fri, 12 Mar 2010 23:20:38 +0000
Subject: refactor: Move another RezSingleAttachment() from Scene.Inventory to
AttachmentsModule
---
.../Region/Framework/Interfaces/IAttachmentsModule.cs | 18 ++++++++++++++++--
1 file changed, 16 insertions(+), 2 deletions(-)
(limited to 'OpenSim/Region/Framework/Interfaces')
diff --git a/OpenSim/Region/Framework/Interfaces/IAttachmentsModule.cs b/OpenSim/Region/Framework/Interfaces/IAttachmentsModule.cs
index 1fa77e4..0222b02 100644
--- a/OpenSim/Region/Framework/Interfaces/IAttachmentsModule.cs
+++ b/OpenSim/Region/Framework/Interfaces/IAttachmentsModule.cs
@@ -59,13 +59,27 @@ namespace OpenSim.Region.Framework.Interfaces
IClientAPI remoteClient, uint objectLocalID, uint AttachmentPt, Quaternion rot, Vector3 attachPos, bool silent);
///
/// Rez an attachment from user inventory
///
///
///
///
/// The scene object that was attached. Null if the scene object could not be found
- SceneObjectGroup RezSingleAttachmentFromInventory(IClientAPI remoteClient, UUID itemID, uint AttachmentPt);
+ UUID RezSingleAttachmentFromInventory(IClientAPI remoteClient, UUID itemID, uint AttachmentPt);
+
+ ///
+ /// Rez an attachment from user inventory
+ ///
+ ///
+ ///
+ ///
+ ///
+ /// If true, we also update the user's inventory to show that the attachment is set. If false, we do not.
+ /// False is required so that we don't attempt to update information when a user enters a scene with the
+ /// attachment already correctly set up in inventory.
+ /// The uuid of the scene object that was attached. Null if the scene object could not be found
+ UUID RezSingleAttachmentFromInventory(
+ IClientAPI remoteClient, UUID itemID, uint AttachmentPt, bool updateInventoryStatus);
///
/// Update the user inventory to the attachment of an item
@@ -59,13 +59,27 @@ namespace OpenSim.Region.Framework.Interfaces
IClientAPI remoteClient, uint objectLocalID, uint AttachmentPt, Quaternion rot, Vector3 attachPos, bool silent);
///
- /// Rez an attachment from user inventory
+ /// Rez an attachment from user inventory and change inventory status to match.
///
///
--
cgit v1.1